fn set_rounding_mode_from_param(rounding_mode: i32) -> RoundingModeGuardExpand description
Helper function to set rounding mode from WASM parameter and return RAII guard Returns a guard that will automatically restore the previous rounding mode
fn set_rounding_mode_from_param(rounding_mode: i32) -> RoundingModeGuardHelper function to set rounding mode from WASM parameter and return RAII guard Returns a guard that will automatically restore the previous rounding mode