struct RoundingModeGuard {
previous_mode: Option<RoundingMode>,
}Expand description
RAII guard for temporarily setting rounding mode Automatically restores the previous rounding mode when dropped
Fields
previous_mode: Option<RoundingMode>Implementations
Sourceimpl RoundingModeGuard
impl RoundingModeGuard
Sourcefn new(mode: NumberRoundingMode) -> Self
fn new(mode: NumberRoundingMode) -> Self
Set a new rounding mode and return a guard that will restore the previous mode